# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['IpV6Args', 'IpV6']

@pulumi.input_type
class IpV6Args:
    def __init__(__self__, *,
                 block: pulumi.Input[_builtins.str],
                 service_name: pulumi.Input[_builtins.str],
                 bridged_subrange: Optional[pulumi.Input['IpV6BridgedSubrangeArgs']] = None):
        """
        The set of arguments for constructing a IpV6 resource.
        :param pulumi.Input[_builtins.str] block: Your IPv6 block.
        :param pulumi.Input[_builtins.str] service_name: The internal name of your vrack
        :param pulumi.Input['IpV6BridgedSubrangeArgs'] bridged_subrange: Bridged subrange configuration.
        """
        pulumi.set(__self__, "block", block)
        pulumi.set(__self__, "service_name", service_name)
        if bridged_subrange is not None:
            pulumi.set(__self__, "bridged_subrange", bridged_subrange)

    @_builtins.property
    @pulumi.getter
    def block(self) -> pulumi.Input[_builtins.str]:
        """
        Your IPv6 block.
        """
        return pulumi.get(self, "block")

    @block.setter
    def block(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "block", value)

    @_builtins.property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Input[_builtins.str]:
        """
        The internal name of your vrack
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "service_name", value)

    @_builtins.property
    @pulumi.getter(name="bridgedSubrange")
    def bridged_subrange(self) -> Optional[pulumi.Input['IpV6BridgedSubrangeArgs']]:
        """
        Bridged subrange configuration.
        """
        return pulumi.get(self, "bridged_subrange")

    @bridged_subrange.setter
    def bridged_subrange(self, value: Optional[pulumi.Input['IpV6BridgedSubrangeArgs']]):
        pulumi.set(self, "bridged_subrange", value)


@pulumi.input_type
class _IpV6State:
    def __init__(__self__, *,
                 block: Optional[pulumi.Input[_builtins.str]] = None,
                 bridged_subrange: Optional[pulumi.Input['IpV6BridgedSubrangeArgs']] = None,
                 ipv6: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 service_name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering IpV6 resources.
        :param pulumi.Input[_builtins.str] block: Your IPv6 block.
        :param pulumi.Input['IpV6BridgedSubrangeArgs'] bridged_subrange: Bridged subrange configuration.
        :param pulumi.Input[_builtins.str] ipv6: The IPv6 block.
        :param pulumi.Input[_builtins.str] region: The region in which the block is routed.
        :param pulumi.Input[_builtins.str] service_name: The internal name of your vrack
        """
        if block is not None:
            pulumi.set(__self__, "block", block)
        if bridged_subrange is not None:
            pulumi.set(__self__, "bridged_subrange", bridged_subrange)
        if ipv6 is not None:
            pulumi.set(__self__, "ipv6", ipv6)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)

    @_builtins.property
    @pulumi.getter
    def block(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Your IPv6 block.
        """
        return pulumi.get(self, "block")

    @block.setter
    def block(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "block", value)

    @_builtins.property
    @pulumi.getter(name="bridgedSubrange")
    def bridged_subrange(self) -> Optional[pulumi.Input['IpV6BridgedSubrangeArgs']]:
        """
        Bridged subrange configuration.
        """
        return pulumi.get(self, "bridged_subrange")

    @bridged_subrange.setter
    def bridged_subrange(self, value: Optional[pulumi.Input['IpV6BridgedSubrangeArgs']]):
        pulumi.set(self, "bridged_subrange", value)

    @_builtins.property
    @pulumi.getter
    def ipv6(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The IPv6 block.
        """
        return pulumi.get(self, "ipv6")

    @ipv6.setter
    def ipv6(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ipv6", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region in which the block is routed.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The internal name of your vrack
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "service_name", value)


@pulumi.type_token("ovh:Vrack/ipV6:IpV6")
class IpV6(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 block: Optional[pulumi.Input[_builtins.str]] = None,
                 bridged_subrange: Optional[pulumi.Input[Union['IpV6BridgedSubrangeArgs', 'IpV6BridgedSubrangeArgsDict']]] = None,
                 service_name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Attach an IPv6 block to a VRack.

        ## Import

        Attachment of an IPv6 block and a VRack can be imported using the `service_name` (vRack identifier) and the `block` (IPv6 block), separated by "," E.g.,

        bash

        ```sh
        $ pulumi import ovh:Vrack/ipV6:IpV6 myattach "<service_name>,<block>"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] block: Your IPv6 block.
        :param pulumi.Input[Union['IpV6BridgedSubrangeArgs', 'IpV6BridgedSubrangeArgsDict']] bridged_subrange: Bridged subrange configuration.
        :param pulumi.Input[_builtins.str] service_name: The internal name of your vrack
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: IpV6Args,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Attach an IPv6 block to a VRack.

        ## Import

        Attachment of an IPv6 block and a VRack can be imported using the `service_name` (vRack identifier) and the `block` (IPv6 block), separated by "," E.g.,

        bash

        ```sh
        $ pulumi import ovh:Vrack/ipV6:IpV6 myattach "<service_name>,<block>"
        ```

        :param str resource_name: The name of the resource.
        :param IpV6Args args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(IpV6Args, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 block: Optional[pulumi.Input[_builtins.str]] = None,
                 bridged_subrange: Optional[pulumi.Input[Union['IpV6BridgedSubrangeArgs', 'IpV6BridgedSubrangeArgsDict']]] = None,
                 service_name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = IpV6Args.__new__(IpV6Args)

            if block is None and not opts.urn:
                raise TypeError("Missing required property 'block'")
            __props__.__dict__["block"] = block
            __props__.__dict__["bridged_subrange"] = bridged_subrange
            if service_name is None and not opts.urn:
                raise TypeError("Missing required property 'service_name'")
            __props__.__dict__["service_name"] = service_name
            __props__.__dict__["ipv6"] = None
            __props__.__dict__["region"] = None
        super(IpV6, __self__).__init__(
            'ovh:Vrack/ipV6:IpV6',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            block: Optional[pulumi.Input[_builtins.str]] = None,
            bridged_subrange: Optional[pulumi.Input[Union['IpV6BridgedSubrangeArgs', 'IpV6BridgedSubrangeArgsDict']]] = None,
            ipv6: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            service_name: Optional[pulumi.Input[_builtins.str]] = None) -> 'IpV6':
        """
        Get an existing IpV6 resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] block: Your IPv6 block.
        :param pulumi.Input[Union['IpV6BridgedSubrangeArgs', 'IpV6BridgedSubrangeArgsDict']] bridged_subrange: Bridged subrange configuration.
        :param pulumi.Input[_builtins.str] ipv6: The IPv6 block.
        :param pulumi.Input[_builtins.str] region: The region in which the block is routed.
        :param pulumi.Input[_builtins.str] service_name: The internal name of your vrack
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _IpV6State.__new__(_IpV6State)

        __props__.__dict__["block"] = block
        __props__.__dict__["bridged_subrange"] = bridged_subrange
        __props__.__dict__["ipv6"] = ipv6
        __props__.__dict__["region"] = region
        __props__.__dict__["service_name"] = service_name
        return IpV6(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def block(self) -> pulumi.Output[_builtins.str]:
        """
        Your IPv6 block.
        """
        return pulumi.get(self, "block")

    @_builtins.property
    @pulumi.getter(name="bridgedSubrange")
    def bridged_subrange(self) -> pulumi.Output['outputs.IpV6BridgedSubrange']:
        """
        Bridged subrange configuration.
        """
        return pulumi.get(self, "bridged_subrange")

    @_builtins.property
    @pulumi.getter
    def ipv6(self) -> pulumi.Output[_builtins.str]:
        """
        The IPv6 block.
        """
        return pulumi.get(self, "ipv6")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[_builtins.str]:
        """
        The region in which the block is routed.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[_builtins.str]:
        """
        The internal name of your vrack
        """
        return pulumi.get(self, "service_name")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetLocationResult',
    'AwaitableGetLocationResult',
    'get_location',
    'get_location_output',
]

@pulumi.output_type
class GetLocationResult:
    """
    A collection of values returned by getLocation.
    """
    def __init__(__self__, availability_zones=None, cardinal_point=None, city_code=None, city_latitude=None, city_longitude=None, city_name=None, code=None, country_code=None, country_name=None, geography_code=None, geography_name=None, id=None, location=None, name=None, opening_year=None, specific_type=None, type=None):
        if availability_zones and not isinstance(availability_zones, list):
            raise TypeError("Expected argument 'availability_zones' to be a list")
        pulumi.set(__self__, "availability_zones", availability_zones)
        if cardinal_point and not isinstance(cardinal_point, str):
            raise TypeError("Expected argument 'cardinal_point' to be a str")
        pulumi.set(__self__, "cardinal_point", cardinal_point)
        if city_code and not isinstance(city_code, str):
            raise TypeError("Expected argument 'city_code' to be a str")
        pulumi.set(__self__, "city_code", city_code)
        if city_latitude and not isinstance(city_latitude, float):
            raise TypeError("Expected argument 'city_latitude' to be a float")
        pulumi.set(__self__, "city_latitude", city_latitude)
        if city_longitude and not isinstance(city_longitude, float):
            raise TypeError("Expected argument 'city_longitude' to be a float")
        pulumi.set(__self__, "city_longitude", city_longitude)
        if city_name and not isinstance(city_name, str):
            raise TypeError("Expected argument 'city_name' to be a str")
        pulumi.set(__self__, "city_name", city_name)
        if code and not isinstance(code, str):
            raise TypeError("Expected argument 'code' to be a str")
        pulumi.set(__self__, "code", code)
        if country_code and not isinstance(country_code, str):
            raise TypeError("Expected argument 'country_code' to be a str")
        pulumi.set(__self__, "country_code", country_code)
        if country_name and not isinstance(country_name, str):
            raise TypeError("Expected argument 'country_name' to be a str")
        pulumi.set(__self__, "country_name", country_name)
        if geography_code and not isinstance(geography_code, str):
            raise TypeError("Expected argument 'geography_code' to be a str")
        pulumi.set(__self__, "geography_code", geography_code)
        if geography_name and not isinstance(geography_name, str):
            raise TypeError("Expected argument 'geography_name' to be a str")
        pulumi.set(__self__, "geography_name", geography_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if location and not isinstance(location, str):
            raise TypeError("Expected argument 'location' to be a str")
        pulumi.set(__self__, "location", location)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if opening_year and not isinstance(opening_year, float):
            raise TypeError("Expected argument 'opening_year' to be a float")
        pulumi.set(__self__, "opening_year", opening_year)
        if specific_type and not isinstance(specific_type, str):
            raise TypeError("Expected argument 'specific_type' to be a str")
        pulumi.set(__self__, "specific_type", specific_type)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter(name="availabilityZones")
    def availability_zones(self) -> Sequence[_builtins.str]:
        """
        List of availability zones for the region
        """
        return pulumi.get(self, "availability_zones")

    @_builtins.property
    @pulumi.getter(name="cardinalPoint")
    def cardinal_point(self) -> _builtins.str:
        """
        Cardinal direction where the region is located
        """
        return pulumi.get(self, "cardinal_point")

    @_builtins.property
    @pulumi.getter(name="cityCode")
    def city_code(self) -> _builtins.str:
        """
        ISO code of the city
        """
        return pulumi.get(self, "city_code")

    @_builtins.property
    @pulumi.getter(name="cityLatitude")
    def city_latitude(self) -> _builtins.float:
        """
        Geographical latitude of the city
        """
        return pulumi.get(self, "city_latitude")

    @_builtins.property
    @pulumi.getter(name="cityLongitude")
    def city_longitude(self) -> _builtins.float:
        """
        Geographical longitude of the city
        """
        return pulumi.get(self, "city_longitude")

    @_builtins.property
    @pulumi.getter(name="cityName")
    def city_name(self) -> _builtins.str:
        """
        Full name of the city
        """
        return pulumi.get(self, "city_name")

    @_builtins.property
    @pulumi.getter
    def code(self) -> _builtins.str:
        """
        Region's short code
        """
        return pulumi.get(self, "code")

    @_builtins.property
    @pulumi.getter(name="countryCode")
    def country_code(self) -> _builtins.str:
        """
        ISO code of the country
        """
        return pulumi.get(self, "country_code")

    @_builtins.property
    @pulumi.getter(name="countryName")
    def country_name(self) -> _builtins.str:
        """
        Full name of the country
        """
        return pulumi.get(self, "country_name")

    @_builtins.property
    @pulumi.getter(name="geographyCode")
    def geography_code(self) -> _builtins.str:
        """
        Short code representing the geographical area
        """
        return pulumi.get(self, "geography_code")

    @_builtins.property
    @pulumi.getter(name="geographyName")
    def geography_name(self) -> _builtins.str:
        """
        Name of the geographical area
        """
        return pulumi.get(self, "geography_name")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def location(self) -> _builtins.str:
        """
        Location of the region
        """
        return pulumi.get(self, "location")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Name
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="openingYear")
    def opening_year(self) -> _builtins.float:
        """
        Year the region was opened
        """
        return pulumi.get(self, "opening_year")

    @_builtins.property
    @pulumi.getter(name="specificType")
    def specific_type(self) -> _builtins.str:
        """
        Specific typology of the region
        """
        return pulumi.get(self, "specific_type")

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        """
        General typology of the region
        """
        return pulumi.get(self, "type")


class AwaitableGetLocationResult(GetLocationResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetLocationResult(
            availability_zones=self.availability_zones,
            cardinal_point=self.cardinal_point,
            city_code=self.city_code,
            city_latitude=self.city_latitude,
            city_longitude=self.city_longitude,
            city_name=self.city_name,
            code=self.code,
            country_code=self.country_code,
            country_name=self.country_name,
            geography_code=self.geography_code,
            geography_name=self.geography_name,
            id=self.id,
            location=self.location,
            name=self.name,
            opening_year=self.opening_year,
            specific_type=self.specific_type,
            type=self.type)


def get_location(name: Optional[_builtins.str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetLocationResult:
    """
    Get available regions and their availability zones

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    paris = ovh.get_location(name="eu-west-par")
    ```


    :param _builtins.str name: Name
    """
    __args__ = dict()
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:index/getLocation:getLocation', __args__, opts=opts, typ=GetLocationResult).value

    return AwaitableGetLocationResult(
        availability_zones=pulumi.get(__ret__, 'availability_zones'),
        cardinal_point=pulumi.get(__ret__, 'cardinal_point'),
        city_code=pulumi.get(__ret__, 'city_code'),
        city_latitude=pulumi.get(__ret__, 'city_latitude'),
        city_longitude=pulumi.get(__ret__, 'city_longitude'),
        city_name=pulumi.get(__ret__, 'city_name'),
        code=pulumi.get(__ret__, 'code'),
        country_code=pulumi.get(__ret__, 'country_code'),
        country_name=pulumi.get(__ret__, 'country_name'),
        geography_code=pulumi.get(__ret__, 'geography_code'),
        geography_name=pulumi.get(__ret__, 'geography_name'),
        id=pulumi.get(__ret__, 'id'),
        location=pulumi.get(__ret__, 'location'),
        name=pulumi.get(__ret__, 'name'),
        opening_year=pulumi.get(__ret__, 'opening_year'),
        specific_type=pulumi.get(__ret__, 'specific_type'),
        type=pulumi.get(__ret__, 'type'))
def get_location_output(name: Optional[pulumi.Input[_builtins.str]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetLocationResult]:
    """
    Get available regions and their availability zones

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    paris = ovh.get_location(name="eu-west-par")
    ```


    :param _builtins.str name: Name
    """
    __args__ = dict()
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:index/getLocation:getLocation', __args__, opts=opts, typ=GetLocationResult)
    return __ret__.apply(lambda __response__: GetLocationResult(
        availability_zones=pulumi.get(__response__, 'availability_zones'),
        cardinal_point=pulumi.get(__response__, 'cardinal_point'),
        city_code=pulumi.get(__response__, 'city_code'),
        city_latitude=pulumi.get(__response__, 'city_latitude'),
        city_longitude=pulumi.get(__response__, 'city_longitude'),
        city_name=pulumi.get(__response__, 'city_name'),
        code=pulumi.get(__response__, 'code'),
        country_code=pulumi.get(__response__, 'country_code'),
        country_name=pulumi.get(__response__, 'country_name'),
        geography_code=pulumi.get(__response__, 'geography_code'),
        geography_name=pulumi.get(__response__, 'geography_name'),
        id=pulumi.get(__response__, 'id'),
        location=pulumi.get(__response__, 'location'),
        name=pulumi.get(__response__, 'name'),
        opening_year=pulumi.get(__response__, 'opening_year'),
        specific_type=pulumi.get(__response__, 'specific_type'),
        type=pulumi.get(__response__, 'type')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['GatewayArgs', 'Gateway']

@pulumi.input_type
class GatewayArgs:
    def __init__(__self__, *,
                 model: pulumi.Input[_builtins.str],
                 network_id: pulumi.Input[_builtins.str],
                 region: pulumi.Input[_builtins.str],
                 subnet_id: pulumi.Input[_builtins.str],
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 service_name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Gateway resource.
        :param pulumi.Input[_builtins.str] model: Model of the gateway.
        :param pulumi.Input[_builtins.str] network_id: ID of the private network.
        :param pulumi.Input[_builtins.str] region: Region of the gateway.
        :param pulumi.Input[_builtins.str] subnet_id: ID of the subnet.
        :param pulumi.Input[_builtins.str] name: Name of the gateway.
        :param pulumi.Input[_builtins.str] service_name: ID of the private network.
        """
        pulumi.set(__self__, "model", model)
        pulumi.set(__self__, "network_id", network_id)
        pulumi.set(__self__, "region", region)
        pulumi.set(__self__, "subnet_id", subnet_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)

    @_builtins.property
    @pulumi.getter
    def model(self) -> pulumi.Input[_builtins.str]:
        """
        Model of the gateway.
        """
        return pulumi.get(self, "model")

    @model.setter
    def model(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "model", value)

    @_builtins.property
    @pulumi.getter(name="networkId")
    def network_id(self) -> pulumi.Input[_builtins.str]:
        """
        ID of the private network.
        """
        return pulumi.get(self, "network_id")

    @network_id.setter
    def network_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "network_id", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Input[_builtins.str]:
        """
        Region of the gateway.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> pulumi.Input[_builtins.str]:
        """
        ID of the subnet.
        """
        return pulumi.get(self, "subnet_id")

    @subnet_id.setter
    def subnet_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "subnet_id", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the gateway.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of the private network.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "service_name", value)


@pulumi.input_type
class _GatewayState:
    def __init__(__self__, *,
                 external_informations: Optional[pulumi.Input[Sequence[pulumi.Input['GatewayExternalInformationArgs']]]] = None,
                 interfaces: Optional[pulumi.Input[Sequence[pulumi.Input['GatewayInterfaceArgs']]]] = None,
                 model: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 network_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 service_name: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 subnet_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Gateway resources.
        :param pulumi.Input[Sequence[pulumi.Input['GatewayExternalInformationArgs']]] external_informations: List of External Information of the gateway.
        :param pulumi.Input[Sequence[pulumi.Input['GatewayInterfaceArgs']]] interfaces: Interfaces list of the gateway.
        :param pulumi.Input[_builtins.str] model: Model of the gateway.
        :param pulumi.Input[_builtins.str] name: Name of the gateway.
        :param pulumi.Input[_builtins.str] network_id: ID of the private network.
        :param pulumi.Input[_builtins.str] region: Region of the gateway.
        :param pulumi.Input[_builtins.str] service_name: ID of the private network.
        :param pulumi.Input[_builtins.str] status: Status of the gateway.
        :param pulumi.Input[_builtins.str] subnet_id: ID of the subnet.
        """
        if external_informations is not None:
            pulumi.set(__self__, "external_informations", external_informations)
        if interfaces is not None:
            pulumi.set(__self__, "interfaces", interfaces)
        if model is not None:
            pulumi.set(__self__, "model", model)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if network_id is not None:
            pulumi.set(__self__, "network_id", network_id)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if subnet_id is not None:
            pulumi.set(__self__, "subnet_id", subnet_id)

    @_builtins.property
    @pulumi.getter(name="externalInformations")
    def external_informations(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GatewayExternalInformationArgs']]]]:
        """
        List of External Information of the gateway.
        """
        return pulumi.get(self, "external_informations")

    @external_informations.setter
    def external_informations(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GatewayExternalInformationArgs']]]]):
        pulumi.set(self, "external_informations", value)

    @_builtins.property
    @pulumi.getter
    def interfaces(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GatewayInterfaceArgs']]]]:
        """
        Interfaces list of the gateway.
        """
        return pulumi.get(self, "interfaces")

    @interfaces.setter
    def interfaces(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GatewayInterfaceArgs']]]]):
        pulumi.set(self, "interfaces", value)

    @_builtins.property
    @pulumi.getter
    def model(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Model of the gateway.
        """
        return pulumi.get(self, "model")

    @model.setter
    def model(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "model", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the gateway.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="networkId")
    def network_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of the private network.
        """
        return pulumi.get(self, "network_id")

    @network_id.setter
    def network_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "network_id", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Region of the gateway.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of the private network.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "service_name", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Status of the gateway.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of the subnet.
        """
        return pulumi.get(self, "subnet_id")

    @subnet_id.setter
    def subnet_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "subnet_id", value)


@pulumi.type_token("ovh:CloudProject/gateway:Gateway")
class Gateway(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 model: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 network_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 service_name: Optional[pulumi.Input[_builtins.str]] = None,
                 subnet_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Create a new Gateway for existing subnet in the specified public cloud project.

        ## Import

        A gateway can be imported using the `service_name`, `region` and `id` (identifier of the gateway) properties, separated by a `/`.

        However, please note that in the case of a gateway import, `network_id` and `subnet_id` values used at gateway creation are not injected back in the state.

        If you want to define these properties on your imported resource, you have to add an "ignore_changes" lifecycle argument in order not to trigger a recreation, as suggested in the following example.

        terraform

        resource "ovh_cloud_project_gateway" "imported_gateway" {

          service_name = ovh_cloud_project_network_private.mypriv.service_name

          name         = "<my-imported-gateway>"

          model        = "<my-model>"

          region       = "<my-region>"

          network_id   = "<my-imported-gateway-network-id>"

          subnet_id    = "<my-imported-gateway-subnet-id>"

          lifecycle {

            ignore_changes = [network_id, subnet_id]

          }

        }

        import {

          id = "<service-name>/<region>/<gateway-id>"

          to = ovh_cloud_project_gateway.imported_gateway

        }

        bash

        ```sh
        $ pulumi import ovh:CloudProject/gateway:Gateway gateway service_name/region/id
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] model: Model of the gateway.
        :param pulumi.Input[_builtins.str] name: Name of the gateway.
        :param pulumi.Input[_builtins.str] network_id: ID of the private network.
        :param pulumi.Input[_builtins.str] region: Region of the gateway.
        :param pulumi.Input[_builtins.str] service_name: ID of the private network.
        :param pulumi.Input[_builtins.str] subnet_id: ID of the subnet.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GatewayArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a new Gateway for existing subnet in the specified public cloud project.

        ## Import

        A gateway can be imported using the `service_name`, `region` and `id` (identifier of the gateway) properties, separated by a `/`.

        However, please note that in the case of a gateway import, `network_id` and `subnet_id` values used at gateway creation are not injected back in the state.

        If you want to define these properties on your imported resource, you have to add an "ignore_changes" lifecycle argument in order not to trigger a recreation, as suggested in the following example.

        terraform

        resource "ovh_cloud_project_gateway" "imported_gateway" {

          service_name = ovh_cloud_project_network_private.mypriv.service_name

          name         = "<my-imported-gateway>"

          model        = "<my-model>"

          region       = "<my-region>"

          network_id   = "<my-imported-gateway-network-id>"

          subnet_id    = "<my-imported-gateway-subnet-id>"

          lifecycle {

            ignore_changes = [network_id, subnet_id]

          }

        }

        import {

          id = "<service-name>/<region>/<gateway-id>"

          to = ovh_cloud_project_gateway.imported_gateway

        }

        bash

        ```sh
        $ pulumi import ovh:CloudProject/gateway:Gateway gateway service_name/region/id
        ```

        :param str resource_name: The name of the resource.
        :param GatewayArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GatewayArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 model: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 network_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 service_name: Optional[pulumi.Input[_builtins.str]] = None,
                 subnet_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GatewayArgs.__new__(GatewayArgs)

            if model is None and not opts.urn:
                raise TypeError("Missing required property 'model'")
            __props__.__dict__["model"] = model
            __props__.__dict__["name"] = name
            if network_id is None and not opts.urn:
                raise TypeError("Missing required property 'network_id'")
            __props__.__dict__["network_id"] = network_id
            if region is None and not opts.urn:
                raise TypeError("Missing required property 'region'")
            __props__.__dict__["region"] = region
            __props__.__dict__["service_name"] = service_name
            if subnet_id is None and not opts.urn:
                raise TypeError("Missing required property 'subnet_id'")
            __props__.__dict__["subnet_id"] = subnet_id
            __props__.__dict__["external_informations"] = None
            __props__.__dict__["interfaces"] = None
            __props__.__dict__["status"] = None
        super(Gateway, __self__).__init__(
            'ovh:CloudProject/gateway:Gateway',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            external_informations: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GatewayExternalInformationArgs', 'GatewayExternalInformationArgsDict']]]]] = None,
            interfaces: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GatewayInterfaceArgs', 'GatewayInterfaceArgsDict']]]]] = None,
            model: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            network_id: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            service_name: Optional[pulumi.Input[_builtins.str]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None,
            subnet_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'Gateway':
        """
        Get an existing Gateway resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['GatewayExternalInformationArgs', 'GatewayExternalInformationArgsDict']]]] external_informations: List of External Information of the gateway.
        :param pulumi.Input[Sequence[pulumi.Input[Union['GatewayInterfaceArgs', 'GatewayInterfaceArgsDict']]]] interfaces: Interfaces list of the gateway.
        :param pulumi.Input[_builtins.str] model: Model of the gateway.
        :param pulumi.Input[_builtins.str] name: Name of the gateway.
        :param pulumi.Input[_builtins.str] network_id: ID of the private network.
        :param pulumi.Input[_builtins.str] region: Region of the gateway.
        :param pulumi.Input[_builtins.str] service_name: ID of the private network.
        :param pulumi.Input[_builtins.str] status: Status of the gateway.
        :param pulumi.Input[_builtins.str] subnet_id: ID of the subnet.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GatewayState.__new__(_GatewayState)

        __props__.__dict__["external_informations"] = external_informations
        __props__.__dict__["interfaces"] = interfaces
        __props__.__dict__["model"] = model
        __props__.__dict__["name"] = name
        __props__.__dict__["network_id"] = network_id
        __props__.__dict__["region"] = region
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["status"] = status
        __props__.__dict__["subnet_id"] = subnet_id
        return Gateway(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="externalInformations")
    def external_informations(self) -> pulumi.Output[Sequence['outputs.GatewayExternalInformation']]:
        """
        List of External Information of the gateway.
        """
        return pulumi.get(self, "external_informations")

    @_builtins.property
    @pulumi.getter
    def interfaces(self) -> pulumi.Output[Sequence['outputs.GatewayInterface']]:
        """
        Interfaces list of the gateway.
        """
        return pulumi.get(self, "interfaces")

    @_builtins.property
    @pulumi.getter
    def model(self) -> pulumi.Output[_builtins.str]:
        """
        Model of the gateway.
        """
        return pulumi.get(self, "model")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the gateway.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="networkId")
    def network_id(self) -> pulumi.Output[_builtins.str]:
        """
        ID of the private network.
        """
        return pulumi.get(self, "network_id")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[_builtins.str]:
        """
        Region of the gateway.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[_builtins.str]:
        """
        ID of the private network.
        """
        return pulumi.get(self, "service_name")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        Status of the gateway.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> pulumi.Output[_builtins.str]:
        """
        ID of the subnet.
        """
        return pulumi.get(self, "subnet_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['GatewayInterfaceInitArgs', 'GatewayInterface']

@pulumi.input_type
class GatewayInterfaceInitArgs:
    def __init__(__self__, *,
                 region: pulumi.Input[_builtins.str],
                 service_name: pulumi.Input[_builtins.str],
                 subnet_id: pulumi.Input[_builtins.str],
                 interface_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a GatewayInterface resource.
        :param pulumi.Input[_builtins.str] region: Region of the gateway
        :param pulumi.Input[_builtins.str] service_name: ID of the cloud project
        :param pulumi.Input[_builtins.str] subnet_id: ID of the subnet to add
        :param pulumi.Input[_builtins.str] interface_id: ID of the interface
        """
        pulumi.set(__self__, "region", region)
        pulumi.set(__self__, "service_name", service_name)
        pulumi.set(__self__, "subnet_id", subnet_id)
        if interface_id is not None:
            pulumi.set(__self__, "interface_id", interface_id)

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Input[_builtins.str]:
        """
        Region of the gateway
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Input[_builtins.str]:
        """
        ID of the cloud project
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "service_name", value)

    @_builtins.property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> pulumi.Input[_builtins.str]:
        """
        ID of the subnet to add
        """
        return pulumi.get(self, "subnet_id")

    @subnet_id.setter
    def subnet_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "subnet_id", value)

    @_builtins.property
    @pulumi.getter(name="interfaceId")
    def interface_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of the interface
        """
        return pulumi.get(self, "interface_id")

    @interface_id.setter
    def interface_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "interface_id", value)


@pulumi.input_type
class _GatewayInterfaceState:
    def __init__(__self__, *,
                 interface_id: Optional[pulumi.Input[_builtins.str]] = None,
                 ip: Optional[pulumi.Input[_builtins.str]] = None,
                 network_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 service_name: Optional[pulumi.Input[_builtins.str]] = None,
                 subnet_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering GatewayInterface resources.
        :param pulumi.Input[_builtins.str] interface_id: ID of the interface
        :param pulumi.Input[_builtins.str] ip: IP of the interface
        :param pulumi.Input[_builtins.str] network_id: Network ID of the interface
        :param pulumi.Input[_builtins.str] region: Region of the gateway
        :param pulumi.Input[_builtins.str] service_name: ID of the cloud project
        :param pulumi.Input[_builtins.str] subnet_id: ID of the subnet to add
        """
        if interface_id is not None:
            pulumi.set(__self__, "interface_id", interface_id)
        if ip is not None:
            pulumi.set(__self__, "ip", ip)
        if network_id is not None:
            pulumi.set(__self__, "network_id", network_id)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if subnet_id is not None:
            pulumi.set(__self__, "subnet_id", subnet_id)

    @_builtins.property
    @pulumi.getter(name="interfaceId")
    def interface_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of the interface
        """
        return pulumi.get(self, "interface_id")

    @interface_id.setter
    def interface_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "interface_id", value)

    @_builtins.property
    @pulumi.getter
    def ip(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        IP of the interface
        """
        return pulumi.get(self, "ip")

    @ip.setter
    def ip(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ip", value)

    @_builtins.property
    @pulumi.getter(name="networkId")
    def network_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Network ID of the interface
        """
        return pulumi.get(self, "network_id")

    @network_id.setter
    def network_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "network_id", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Region of the gateway
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of the cloud project
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "service_name", value)

    @_builtins.property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of the subnet to add
        """
        return pulumi.get(self, "subnet_id")

    @subnet_id.setter
    def subnet_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "subnet_id", value)


@pulumi.type_token("ovh:CloudProject/gatewayInterface:GatewayInterface")
class GatewayInterface(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 interface_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 service_name: Optional[pulumi.Input[_builtins.str]] = None,
                 subnet_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Create a new Gateway Interface for existing subnet in the specified public cloud project.

        ## Import

        A gateway interface can be imported using the `service_name`, `region`, `id` (identifier of the gateway) and `interface_id` properties, separated by a `/`.

        bash

        ```sh
        $ pulumi import ovh:CloudProject/gatewayInterface:GatewayInterface gateway service_name/region/id/interface_id
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] interface_id: ID of the interface
        :param pulumi.Input[_builtins.str] region: Region of the gateway
        :param pulumi.Input[_builtins.str] service_name: ID of the cloud project
        :param pulumi.Input[_builtins.str] subnet_id: ID of the subnet to add
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GatewayInterfaceInitArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a new Gateway Interface for existing subnet in the specified public cloud project.

        ## Import

        A gateway interface can be imported using the `service_name`, `region`, `id` (identifier of the gateway) and `interface_id` properties, separated by a `/`.

        bash

        ```sh
        $ pulumi import ovh:CloudProject/gatewayInterface:GatewayInterface gateway service_name/region/id/interface_id
        ```

        :param str resource_name: The name of the resource.
        :param GatewayInterfaceInitArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GatewayInterfaceInitArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 interface_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 service_name: Optional[pulumi.Input[_builtins.str]] = None,
                 subnet_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GatewayInterfaceInitArgs.__new__(GatewayInterfaceInitArgs)

            __props__.__dict__["interface_id"] = interface_id
            if region is None and not opts.urn:
                raise TypeError("Missing required property 'region'")
            __props__.__dict__["region"] = region
            if service_name is None and not opts.urn:
                raise TypeError("Missing required property 'service_name'")
            __props__.__dict__["service_name"] = service_name
            if subnet_id is None and not opts.urn:
                raise TypeError("Missing required property 'subnet_id'")
            __props__.__dict__["subnet_id"] = subnet_id
            __props__.__dict__["ip"] = None
            __props__.__dict__["network_id"] = None
        super(GatewayInterface, __self__).__init__(
            'ovh:CloudProject/gatewayInterface:GatewayInterface',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            interface_id: Optional[pulumi.Input[_builtins.str]] = None,
            ip: Optional[pulumi.Input[_builtins.str]] = None,
            network_id: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            service_name: Optional[pulumi.Input[_builtins.str]] = None,
            subnet_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'GatewayInterface':
        """
        Get an existing GatewayInterface resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] interface_id: ID of the interface
        :param pulumi.Input[_builtins.str] ip: IP of the interface
        :param pulumi.Input[_builtins.str] network_id: Network ID of the interface
        :param pulumi.Input[_builtins.str] region: Region of the gateway
        :param pulumi.Input[_builtins.str] service_name: ID of the cloud project
        :param pulumi.Input[_builtins.str] subnet_id: ID of the subnet to add
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GatewayInterfaceState.__new__(_GatewayInterfaceState)

        __props__.__dict__["interface_id"] = interface_id
        __props__.__dict__["ip"] = ip
        __props__.__dict__["network_id"] = network_id
        __props__.__dict__["region"] = region
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["subnet_id"] = subnet_id
        return GatewayInterface(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="interfaceId")
    def interface_id(self) -> pulumi.Output[_builtins.str]:
        """
        ID of the interface
        """
        return pulumi.get(self, "interface_id")

    @_builtins.property
    @pulumi.getter
    def ip(self) -> pulumi.Output[_builtins.str]:
        """
        IP of the interface
        """
        return pulumi.get(self, "ip")

    @_builtins.property
    @pulumi.getter(name="networkId")
    def network_id(self) -> pulumi.Output[_builtins.str]:
        """
        Network ID of the interface
        """
        return pulumi.get(self, "network_id")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[_builtins.str]:
        """
        Region of the gateway
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[_builtins.str]:
        """
        ID of the cloud project
        """
        return pulumi.get(self, "service_name")

    @_builtins.property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> pulumi.Output[_builtins.str]:
        """
        ID of the subnet to add
        """
        return pulumi.get(self, "subnet_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['DynhostLoginArgs', 'DynhostLogin']

@pulumi.input_type
class DynhostLoginArgs:
    def __init__(__self__, *,
                 login_suffix: pulumi.Input[_builtins.str],
                 password: pulumi.Input[_builtins.str],
                 sub_domain: pulumi.Input[_builtins.str],
                 zone_name: pulumi.Input[_builtins.str]):
        """
        The set of arguments for constructing a DynhostLogin resource.
        :param pulumi.Input[_builtins.str] login_suffix: Suffix that will be concatenated to the zoneName to create the login
        :param pulumi.Input[_builtins.str] password: Password of the login
        :param pulumi.Input[_builtins.str] sub_domain: Subdomain that the login will be allowed to update (use * to allow all)
        :param pulumi.Input[_builtins.str] zone_name: Zone name
        """
        pulumi.set(__self__, "login_suffix", login_suffix)
        pulumi.set(__self__, "password", password)
        pulumi.set(__self__, "sub_domain", sub_domain)
        pulumi.set(__self__, "zone_name", zone_name)

    @_builtins.property
    @pulumi.getter(name="loginSuffix")
    def login_suffix(self) -> pulumi.Input[_builtins.str]:
        """
        Suffix that will be concatenated to the zoneName to create the login
        """
        return pulumi.get(self, "login_suffix")

    @login_suffix.setter
    def login_suffix(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "login_suffix", value)

    @_builtins.property
    @pulumi.getter
    def password(self) -> pulumi.Input[_builtins.str]:
        """
        Password of the login
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "password", value)

    @_builtins.property
    @pulumi.getter(name="subDomain")
    def sub_domain(self) -> pulumi.Input[_builtins.str]:
        """
        Subdomain that the login will be allowed to update (use * to allow all)
        """
        return pulumi.get(self, "sub_domain")

    @sub_domain.setter
    def sub_domain(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "sub_domain", value)

    @_builtins.property
    @pulumi.getter(name="zoneName")
    def zone_name(self) -> pulumi.Input[_builtins.str]:
        """
        Zone name
        """
        return pulumi.get(self, "zone_name")

    @zone_name.setter
    def zone_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "zone_name", value)


@pulumi.input_type
class _DynhostLoginState:
    def __init__(__self__, *,
                 login: Optional[pulumi.Input[_builtins.str]] = None,
                 login_suffix: Optional[pulumi.Input[_builtins.str]] = None,
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 sub_domain: Optional[pulumi.Input[_builtins.str]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None,
                 zone_name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering DynhostLogin resources.
        :param pulumi.Input[_builtins.str] login: Login name
        :param pulumi.Input[_builtins.str] login_suffix: Suffix that will be concatenated to the zoneName to create the login
        :param pulumi.Input[_builtins.str] password: Password of the login
        :param pulumi.Input[_builtins.str] sub_domain: Subdomain that the login will be allowed to update (use * to allow all)
        :param pulumi.Input[_builtins.str] zone: Login zone
        :param pulumi.Input[_builtins.str] zone_name: Zone name
        """
        if login is not None:
            pulumi.set(__self__, "login", login)
        if login_suffix is not None:
            pulumi.set(__self__, "login_suffix", login_suffix)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if sub_domain is not None:
            pulumi.set(__self__, "sub_domain", sub_domain)
        if zone is not None:
            pulumi.set(__self__, "zone", zone)
        if zone_name is not None:
            pulumi.set(__self__, "zone_name", zone_name)

    @_builtins.property
    @pulumi.getter
    def login(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Login name
        """
        return pulumi.get(self, "login")

    @login.setter
    def login(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "login", value)

    @_builtins.property
    @pulumi.getter(name="loginSuffix")
    def login_suffix(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Suffix that will be concatenated to the zoneName to create the login
        """
        return pulumi.get(self, "login_suffix")

    @login_suffix.setter
    def login_suffix(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "login_suffix", value)

    @_builtins.property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Password of the login
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "password", value)

    @_builtins.property
    @pulumi.getter(name="subDomain")
    def sub_domain(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Subdomain that the login will be allowed to update (use * to allow all)
        """
        return pulumi.get(self, "sub_domain")

    @sub_domain.setter
    def sub_domain(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sub_domain", value)

    @_builtins.property
    @pulumi.getter
    def zone(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Login zone
        """
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "zone", value)

    @_builtins.property
    @pulumi.getter(name="zoneName")
    def zone_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Zone name
        """
        return pulumi.get(self, "zone_name")

    @zone_name.setter
    def zone_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "zone_name", value)


@pulumi.type_token("ovh:Domain/dynhostLogin:DynhostLogin")
class DynhostLogin(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 login_suffix: Optional[pulumi.Input[_builtins.str]] = None,
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 sub_domain: Optional[pulumi.Input[_builtins.str]] = None,
                 zone_name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Create a dynhost login for a given domain zone.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        dynhost_user = ovh.domain.DynhostLogin("dynhost_user",
            zone_name="mydomain.ovh",
            sub_domain="dynhost",
            login_suffix="dynhostUser",
            password="thisIsMyPassword")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] login_suffix: Suffix that will be concatenated to the zoneName to create the login
        :param pulumi.Input[_builtins.str] password: Password of the login
        :param pulumi.Input[_builtins.str] sub_domain: Subdomain that the login will be allowed to update (use * to allow all)
        :param pulumi.Input[_builtins.str] zone_name: Zone name
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DynhostLoginArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a dynhost login for a given domain zone.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        dynhost_user = ovh.domain.DynhostLogin("dynhost_user",
            zone_name="mydomain.ovh",
            sub_domain="dynhost",
            login_suffix="dynhostUser",
            password="thisIsMyPassword")
        ```

        :param str resource_name: The name of the resource.
        :param DynhostLoginArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DynhostLoginArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 login_suffix: Optional[pulumi.Input[_builtins.str]] = None,
                 password: Optional[pulumi.Input[_builtins.str]] = None,
                 sub_domain: Optional[pulumi.Input[_builtins.str]] = None,
                 zone_name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DynhostLoginArgs.__new__(DynhostLoginArgs)

            if login_suffix is None and not opts.urn:
                raise TypeError("Missing required property 'login_suffix'")
            __props__.__dict__["login_suffix"] = login_suffix
            if password is None and not opts.urn:
                raise TypeError("Missing required property 'password'")
            __props__.__dict__["password"] = None if password is None else pulumi.Output.secret(password)
            if sub_domain is None and not opts.urn:
                raise TypeError("Missing required property 'sub_domain'")
            __props__.__dict__["sub_domain"] = sub_domain
            if zone_name is None and not opts.urn:
                raise TypeError("Missing required property 'zone_name'")
            __props__.__dict__["zone_name"] = zone_name
            __props__.__dict__["login"] = None
            __props__.__dict__["zone"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["password"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(DynhostLogin, __self__).__init__(
            'ovh:Domain/dynhostLogin:DynhostLogin',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            login: Optional[pulumi.Input[_builtins.str]] = None,
            login_suffix: Optional[pulumi.Input[_builtins.str]] = None,
            password: Optional[pulumi.Input[_builtins.str]] = None,
            sub_domain: Optional[pulumi.Input[_builtins.str]] = None,
            zone: Optional[pulumi.Input[_builtins.str]] = None,
            zone_name: Optional[pulumi.Input[_builtins.str]] = None) -> 'DynhostLogin':
        """
        Get an existing DynhostLogin resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] login: Login name
        :param pulumi.Input[_builtins.str] login_suffix: Suffix that will be concatenated to the zoneName to create the login
        :param pulumi.Input[_builtins.str] password: Password of the login
        :param pulumi.Input[_builtins.str] sub_domain: Subdomain that the login will be allowed to update (use * to allow all)
        :param pulumi.Input[_builtins.str] zone: Login zone
        :param pulumi.Input[_builtins.str] zone_name: Zone name
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DynhostLoginState.__new__(_DynhostLoginState)

        __props__.__dict__["login"] = login
        __props__.__dict__["login_suffix"] = login_suffix
        __props__.__dict__["password"] = password
        __props__.__dict__["sub_domain"] = sub_domain
        __props__.__dict__["zone"] = zone
        __props__.__dict__["zone_name"] = zone_name
        return DynhostLogin(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def login(self) -> pulumi.Output[_builtins.str]:
        """
        Login name
        """
        return pulumi.get(self, "login")

    @_builtins.property
    @pulumi.getter(name="loginSuffix")
    def login_suffix(self) -> pulumi.Output[_builtins.str]:
        """
        Suffix that will be concatenated to the zoneName to create the login
        """
        return pulumi.get(self, "login_suffix")

    @_builtins.property
    @pulumi.getter
    def password(self) -> pulumi.Output[_builtins.str]:
        """
        Password of the login
        """
        return pulumi.get(self, "password")

    @_builtins.property
    @pulumi.getter(name="subDomain")
    def sub_domain(self) -> pulumi.Output[_builtins.str]:
        """
        Subdomain that the login will be allowed to update (use * to allow all)
        """
        return pulumi.get(self, "sub_domain")

    @_builtins.property
    @pulumi.getter
    def zone(self) -> pulumi.Output[_builtins.str]:
        """
        Login zone
        """
        return pulumi.get(self, "zone")

    @_builtins.property
    @pulumi.getter(name="zoneName")
    def zone_name(self) -> pulumi.Output[_builtins.str]:
        """
        Zone name
        """
        return pulumi.get(self, "zone_name")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['UdpFarmServerArgs', 'UdpFarmServer']

@pulumi.input_type
class UdpFarmServerArgs:
    def __init__(__self__, *,
                 address: pulumi.Input[_builtins.str],
                 farm_id: pulumi.Input[_builtins.float],
                 service_name: pulumi.Input[_builtins.str],
                 status: pulumi.Input[_builtins.str],
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 port: Optional[pulumi.Input[_builtins.float]] = None):
        """
        The set of arguments for constructing a UdpFarmServer resource.
        :param pulumi.Input[_builtins.str] address: Address of the backend server (IP from either internal or OVHcloud network)
        :param pulumi.Input[_builtins.float] farm_id: ID of the farm this server is attached to
        :param pulumi.Input[_builtins.str] service_name: The internal name of your IP load balancing
        :param pulumi.Input[_builtins.str] status: backend status - `active` or `inactive`
        :param pulumi.Input[_builtins.str] display_name: Label for the server
        :param pulumi.Input[_builtins.float] port: Port that backend will respond on
        """
        pulumi.set(__self__, "address", address)
        pulumi.set(__self__, "farm_id", farm_id)
        pulumi.set(__self__, "service_name", service_name)
        pulumi.set(__self__, "status", status)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if port is not None:
            pulumi.set(__self__, "port", port)

    @_builtins.property
    @pulumi.getter
    def address(self) -> pulumi.Input[_builtins.str]:
        """
        Address of the backend server (IP from either internal or OVHcloud network)
        """
        return pulumi.get(self, "address")

    @address.setter
    def address(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "address", value)

    @_builtins.property
    @pulumi.getter(name="farmId")
    def farm_id(self) -> pulumi.Input[_builtins.float]:
        """
        ID of the farm this server is attached to
        """
        return pulumi.get(self, "farm_id")

    @farm_id.setter
    def farm_id(self, value: pulumi.Input[_builtins.float]):
        pulumi.set(self, "farm_id", value)

    @_builtins.property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Input[_builtins.str]:
        """
        The internal name of your IP load balancing
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "service_name", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Input[_builtins.str]:
        """
        backend status - `active` or `inactive`
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Label for the server
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "display_name", value)

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[_builtins.float]]:
        """
        Port that backend will respond on
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[_builtins.float]]):
        pulumi.set(self, "port", value)


@pulumi.input_type
class _UdpFarmServerState:
    def __init__(__self__, *,
                 address: Optional[pulumi.Input[_builtins.str]] = None,
                 backend_id: Optional[pulumi.Input[_builtins.float]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 farm_id: Optional[pulumi.Input[_builtins.float]] = None,
                 port: Optional[pulumi.Input[_builtins.float]] = None,
                 server_id: Optional[pulumi.Input[_builtins.float]] = None,
                 service_name: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering UdpFarmServer resources.
        :param pulumi.Input[_builtins.str] address: Address of the backend server (IP from either internal or OVHcloud network)
        :param pulumi.Input[_builtins.float] backend_id: Synonym for `farm_id`.
        :param pulumi.Input[_builtins.str] display_name: Label for the server
        :param pulumi.Input[_builtins.float] farm_id: ID of the farm this server is attached to
        :param pulumi.Input[_builtins.float] port: Port that backend will respond on
        :param pulumi.Input[_builtins.float] server_id: Id of your server.
        :param pulumi.Input[_builtins.str] service_name: The internal name of your IP load balancing
        :param pulumi.Input[_builtins.str] status: backend status - `active` or `inactive`
        """
        if address is not None:
            pulumi.set(__self__, "address", address)
        if backend_id is not None:
            pulumi.set(__self__, "backend_id", backend_id)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if farm_id is not None:
            pulumi.set(__self__, "farm_id", farm_id)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if server_id is not None:
            pulumi.set(__self__, "server_id", server_id)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter
    def address(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Address of the backend server (IP from either internal or OVHcloud network)
        """
        return pulumi.get(self, "address")

    @address.setter
    def address(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "address", value)

    @_builtins.property
    @pulumi.getter(name="backendId")
    def backend_id(self) -> Optional[pulumi.Input[_builtins.float]]:
        """
        Synonym for `farm_id`.
        """
        return pulumi.get(self, "backend_id")

    @backend_id.setter
    def backend_id(self, value: Optional[pulumi.Input[_builtins.float]]):
        pulumi.set(self, "backend_id", value)

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Label for the server
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "display_name", value)

    @_builtins.property
    @pulumi.getter(name="farmId")
    def farm_id(self) -> Optional[pulumi.Input[_builtins.float]]:
        """
        ID of the farm this server is attached to
        """
        return pulumi.get(self, "farm_id")

    @farm_id.setter
    def farm_id(self, value: Optional[pulumi.Input[_builtins.float]]):
        pulumi.set(self, "farm_id", value)

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[_builtins.float]]:
        """
        Port that backend will respond on
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[_builtins.float]]):
        pulumi.set(self, "port", value)

    @_builtins.property
    @pulumi.getter(name="serverId")
    def server_id(self) -> Optional[pulumi.Input[_builtins.float]]:
        """
        Id of your server.
        """
        return pulumi.get(self, "server_id")

    @server_id.setter
    def server_id(self, value: Optional[pulumi.Input[_builtins.float]]):
        pulumi.set(self, "server_id", value)

    @_builtins.property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The internal name of your IP load balancing
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "service_name", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        backend status - `active` or `inactive`
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.type_token("ovh:IpLoadBalancing/udpFarmServer:UdpFarmServer")
class UdpFarmServer(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 address: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 farm_id: Optional[pulumi.Input[_builtins.float]] = None,
                 port: Optional[pulumi.Input[_builtins.float]] = None,
                 service_name: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Creates a backend server entry linked to loadbalancing group (farm)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        lb = ovh.IpLoadBalancing.get_ip_load_balancing(service_name="ip-1.2.3.4",
            state="ok")
        farm_name = ovh.iploadbalancing.UdpFarm("farm_name",
            service_name=lb.service_name,
            display_name="ingress-8080-gra",
            zone="gra",
            port=80)
        backend = ovh.iploadbalancing.UdpFarmServer("backend",
            service_name=lb.service_name,
            farm_id=farm_name.farm_id,
            display_name="mybackend",
            address="4.5.6.7",
            status="active",
            port=80)
        ```

        ## Import

        UDP farm server can be imported using the following format `service_name`, the `id` of the farm and the `id` of the server separated by "/" e.g.

        bash

        ```sh
        $ pulumi import ovh:IpLoadBalancing/udpFarmServer:UdpFarmServer backend service_name/farm_id/server_id
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] address: Address of the backend server (IP from either internal or OVHcloud network)
        :param pulumi.Input[_builtins.str] display_name: Label for the server
        :param pulumi.Input[_builtins.float] farm_id: ID of the farm this server is attached to
        :param pulumi.Input[_builtins.float] port: Port that backend will respond on
        :param pulumi.Input[_builtins.str] service_name: The internal name of your IP load balancing
        :param pulumi.Input[_builtins.str] status: backend status - `active` or `inactive`
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: UdpFarmServerArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates a backend server entry linked to loadbalancing group (farm)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        lb = ovh.IpLoadBalancing.get_ip_load_balancing(service_name="ip-1.2.3.4",
            state="ok")
        farm_name = ovh.iploadbalancing.UdpFarm("farm_name",
            service_name=lb.service_name,
            display_name="ingress-8080-gra",
            zone="gra",
            port=80)
        backend = ovh.iploadbalancing.UdpFarmServer("backend",
            service_name=lb.service_name,
            farm_id=farm_name.farm_id,
            display_name="mybackend",
            address="4.5.6.7",
            status="active",
            port=80)
        ```

        ## Import

        UDP farm server can be imported using the following format `service_name`, the `id` of the farm and the `id` of the server separated by "/" e.g.

        bash

        ```sh
        $ pulumi import ovh:IpLoadBalancing/udpFarmServer:UdpFarmServer backend service_name/farm_id/server_id
        ```

        :param str resource_name: The name of the resource.
        :param UdpFarmServerArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(UdpFarmServerArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 address: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 farm_id: Optional[pulumi.Input[_builtins.float]] = None,
                 port: Optional[pulumi.Input[_builtins.float]] = None,
                 service_name: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = UdpFarmServerArgs.__new__(UdpFarmServerArgs)

            if address is None and not opts.urn:
                raise TypeError("Missing required property 'address'")
            __props__.__dict__["address"] = address
            __props__.__dict__["display_name"] = display_name
            if farm_id is None and not opts.urn:
                raise TypeError("Missing required property 'farm_id'")
            __props__.__dict__["farm_id"] = farm_id
            __props__.__dict__["port"] = port
            if service_name is None and not opts.urn:
                raise TypeError("Missing required property 'service_name'")
            __props__.__dict__["service_name"] = service_name
            if status is None and not opts.urn:
                raise TypeError("Missing required property 'status'")
            __props__.__dict__["status"] = status
            __props__.__dict__["backend_id"] = None
            __props__.__dict__["server_id"] = None
        super(UdpFarmServer, __self__).__init__(
            'ovh:IpLoadBalancing/udpFarmServer:UdpFarmServer',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            address: Optional[pulumi.Input[_builtins.str]] = None,
            backend_id: Optional[pulumi.Input[_builtins.float]] = None,
            display_name: Optional[pulumi.Input[_builtins.str]] = None,
            farm_id: Optional[pulumi.Input[_builtins.float]] = None,
            port: Optional[pulumi.Input[_builtins.float]] = None,
            server_id: Optional[pulumi.Input[_builtins.float]] = None,
            service_name: Optional[pulumi.Input[_builtins.str]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None) -> 'UdpFarmServer':
        """
        Get an existing UdpFarmServer resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] address: Address of the backend server (IP from either internal or OVHcloud network)
        :param pulumi.Input[_builtins.float] backend_id: Synonym for `farm_id`.
        :param pulumi.Input[_builtins.str] display_name: Label for the server
        :param pulumi.Input[_builtins.float] farm_id: ID of the farm this server is attached to
        :param pulumi.Input[_builtins.float] port: Port that backend will respond on
        :param pulumi.Input[_builtins.float] server_id: Id of your server.
        :param pulumi.Input[_builtins.str] service_name: The internal name of your IP load balancing
        :param pulumi.Input[_builtins.str] status: backend status - `active` or `inactive`
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _UdpFarmServerState.__new__(_UdpFarmServerState)

        __props__.__dict__["address"] = address
        __props__.__dict__["backend_id"] = backend_id
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["farm_id"] = farm_id
        __props__.__dict__["port"] = port
        __props__.__dict__["server_id"] = server_id
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["status"] = status
        return UdpFarmServer(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def address(self) -> pulumi.Output[_builtins.str]:
        """
        Address of the backend server (IP from either internal or OVHcloud network)
        """
        return pulumi.get(self, "address")

    @_builtins.property
    @pulumi.getter(name="backendId")
    def backend_id(self) -> pulumi.Output[_builtins.float]:
        """
        Synonym for `farm_id`.
        """
        return pulumi.get(self, "backend_id")

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Label for the server
        """
        return pulumi.get(self, "display_name")

    @_builtins.property
    @pulumi.getter(name="farmId")
    def farm_id(self) -> pulumi.Output[_builtins.float]:
        """
        ID of the farm this server is attached to
        """
        return pulumi.get(self, "farm_id")

    @_builtins.property
    @pulumi.getter
    def port(self) -> pulumi.Output[Optional[_builtins.float]]:
        """
        Port that backend will respond on
        """
        return pulumi.get(self, "port")

    @_builtins.property
    @pulumi.getter(name="serverId")
    def server_id(self) -> pulumi.Output[_builtins.float]:
        """
        Id of your server.
        """
        return pulumi.get(self, "server_id")

    @_builtins.property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[_builtins.str]:
        """
        The internal name of your IP load balancing
        """
        return pulumi.get(self, "service_name")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        backend status - `active` or `inactive`
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'IpV6BridgedSubrange',
    'VrackOrder',
    'VrackOrderDetail',
    'VrackPlan',
    'VrackPlanConfiguration',
    'VrackPlanOption',
    'VrackPlanOptionConfiguration',
]

@pulumi.output_type
class IpV6BridgedSubrange(dict):
    def __init__(__self__, *,
                 slaac: _builtins.str,
                 gateway: Optional[_builtins.str] = None,
                 subrange: Optional[_builtins.str] = None):
        """
        :param _builtins.str slaac: Slaac status <enabled|disabled>
        :param _builtins.str gateway: Your gateway
        :param _builtins.str subrange: IPv6 CIDR notation (e.g., 2001:41d0::/128)
        """
        pulumi.set(__self__, "slaac", slaac)
        if gateway is not None:
            pulumi.set(__self__, "gateway", gateway)
        if subrange is not None:
            pulumi.set(__self__, "subrange", subrange)

    @_builtins.property
    @pulumi.getter
    def slaac(self) -> _builtins.str:
        """
        Slaac status <enabled|disabled>
        """
        return pulumi.get(self, "slaac")

    @_builtins.property
    @pulumi.getter
    def gateway(self) -> Optional[_builtins.str]:
        """
        Your gateway
        """
        return pulumi.get(self, "gateway")

    @_builtins.property
    @pulumi.getter
    def subrange(self) -> Optional[_builtins.str]:
        """
        IPv6 CIDR notation (e.g., 2001:41d0::/128)
        """
        return pulumi.get(self, "subrange")


@pulumi.output_type
class VrackOrder(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "expirationDate":
            suggest = "expiration_date"
        elif key == "orderId":
            suggest = "order_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in VrackOrder. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        VrackOrder.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        VrackOrder.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 date: Optional[_builtins.str] = None,
                 details: Optional[Sequence['outputs.VrackOrderDetail']] = None,
                 expiration_date: Optional[_builtins.str] = None,
                 order_id: Optional[_builtins.int] = None):
        """
        :param _builtins.str date: date
        :param Sequence['VrackOrderDetailArgs'] details: Information about a Bill entry
        :param _builtins.str expiration_date: expiration date
        :param _builtins.int order_id: order id
        """
        if date is not None:
            pulumi.set(__self__, "date", date)
        if details is not None:
            pulumi.set(__self__, "details", details)
        if expiration_date is not None:
            pulumi.set(__self__, "expiration_date", expiration_date)
        if order_id is not None:
            pulumi.set(__self__, "order_id", order_id)

    @_builtins.property
    @pulumi.getter
    def date(self) -> Optional[_builtins.str]:
        """
        date
        """
        return pulumi.get(self, "date")

    @_builtins.property
    @pulumi.getter
    def details(self) -> Optional[Sequence['outputs.VrackOrderDetail']]:
        """
        Information about a Bill entry
        """
        return pulumi.get(self, "details")

    @_builtins.property
    @pulumi.getter(name="expirationDate")
    def expiration_date(self) -> Optional[_builtins.str]:
        """
        expiration date
        """
        return pulumi.get(self, "expiration_date")

    @_builtins.property
    @pulumi.getter(name="orderId")
    def order_id(self) -> Optional[_builtins.int]:
        """
        order id
        """
        return pulumi.get(self, "order_id")


@pulumi.output_type
class VrackOrderDetail(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "orderDetailId":
            suggest = "order_detail_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in VrackOrderDetail. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        VrackOrderDetail.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        VrackOrderDetail.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 description: Optional[_builtins.str] = None,
                 domain: Optional[_builtins.str] = None,
                 order_detail_id: Optional[_builtins.int] = None,
                 quantity: Optional[_builtins.str] = None):
        """
        :param _builtins.str description: yourvrackdescription
        :param _builtins.str domain: expiration date
        :param _builtins.int order_detail_id: order detail id
        :param _builtins.str quantity: quantity
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if domain is not None:
            pulumi.set(__self__, "domain", domain)
        if order_detail_id is not None:
            pulumi.set(__self__, "order_detail_id", order_detail_id)
        if quantity is not None:
            pulumi.set(__self__, "quantity", quantity)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[_builtins.str]:
        """
        yourvrackdescription
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def domain(self) -> Optional[_builtins.str]:
        """
        expiration date
        """
        return pulumi.get(self, "domain")

    @_builtins.property
    @pulumi.getter(name="orderDetailId")
    def order_detail_id(self) -> Optional[_builtins.int]:
        """
        order detail id
        """
        return pulumi.get(self, "order_detail_id")

    @_builtins.property
    @pulumi.getter
    def quantity(self) -> Optional[_builtins.str]:
        """
        quantity
        """
        return pulumi.get(self, "quantity")


@pulumi.output_type
class VrackPlan(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "planCode":
            suggest = "plan_code"
        elif key == "pricingMode":
            suggest = "pricing_mode"
        elif key == "catalogName":
            suggest = "catalog_name"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in VrackPlan. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        VrackPlan.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        VrackPlan.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 duration: _builtins.str,
                 plan_code: _builtins.str,
                 pricing_mode: _builtins.str,
                 catalog_name: Optional[_builtins.str] = None,
                 configurations: Optional[Sequence['outputs.VrackPlanConfiguration']] = None):
        """
        :param _builtins.str duration: duration
        :param _builtins.str plan_code: Plan code
        :param _builtins.str pricing_mode: Pricing model identifier
        :param _builtins.str catalog_name: Catalog name
        :param Sequence['VrackPlanConfigurationArgs'] configurations: Representation of a configuration item for personalizing product
        """
        pulumi.set(__self__, "duration", duration)
        pulumi.set(__self__, "plan_code", plan_code)
        pulumi.set(__self__, "pricing_mode", pricing_mode)
        if catalog_name is not None:
            pulumi.set(__self__, "catalog_name", catalog_name)
        if configurations is not None:
            pulumi.set(__self__, "configurations", configurations)

    @_builtins.property
    @pulumi.getter
    def duration(self) -> _builtins.str:
        """
        duration
        """
        return pulumi.get(self, "duration")

    @_builtins.property
    @pulumi.getter(name="planCode")
    def plan_code(self) -> _builtins.str:
        """
        Plan code
        """
        return pulumi.get(self, "plan_code")

    @_builtins.property
    @pulumi.getter(name="pricingMode")
    def pricing_mode(self) -> _builtins.str:
        """
        Pricing model identifier
        """
        return pulumi.get(self, "pricing_mode")

    @_builtins.property
    @pulumi.getter(name="catalogName")
    def catalog_name(self) -> Optional[_builtins.str]:
        """
        Catalog name
        """
        return pulumi.get(self, "catalog_name")

    @_builtins.property
    @pulumi.getter
    def configurations(self) -> Optional[Sequence['outputs.VrackPlanConfiguration']]:
        """
        Representation of a configuration item for personalizing product
        """
        return pulumi.get(self, "configurations")


@pulumi.output_type
class VrackPlanConfiguration(dict):
    def __init__(__self__, *,
                 label: _builtins.str,
                 value: _builtins.str):
        """
        :param _builtins.str label: Identifier of the resource
        :param _builtins.str value: Path to the resource in API.OVH.COM
        """
        pulumi.set(__self__, "label", label)
        pulumi.set(__self__, "value", value)

    @_builtins.property
    @pulumi.getter
    def label(self) -> _builtins.str:
        """
        Identifier of the resource
        """
        return pulumi.get(self, "label")

    @_builtins.property
    @pulumi.getter
    def value(self) -> _builtins.str:
        """
        Path to the resource in API.OVH.COM
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class VrackPlanOption(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "planCode":
            suggest = "plan_code"
        elif key == "pricingMode":
            suggest = "pricing_mode"
        elif key == "catalogName":
            suggest = "catalog_name"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in VrackPlanOption. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        VrackPlanOption.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        VrackPlanOption.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 duration: _builtins.str,
                 plan_code: _builtins.str,
                 pricing_mode: _builtins.str,
                 catalog_name: Optional[_builtins.str] = None,
                 configurations: Optional[Sequence['outputs.VrackPlanOptionConfiguration']] = None):
        """
        :param _builtins.str duration: duration
        :param _builtins.str plan_code: Plan code
        :param _builtins.str pricing_mode: Pricing model identifier
        :param _builtins.str catalog_name: Catalog name
        :param Sequence['VrackPlanOptionConfigurationArgs'] configurations: Representation of a configuration item for personalizing product
        """
        pulumi.set(__self__, "duration", duration)
        pulumi.set(__self__, "plan_code", plan_code)
        pulumi.set(__self__, "pricing_mode", pricing_mode)
        if catalog_name is not None:
            pulumi.set(__self__, "catalog_name", catalog_name)
        if configurations is not None:
            pulumi.set(__self__, "configurations", configurations)

    @_builtins.property
    @pulumi.getter
    def duration(self) -> _builtins.str:
        """
        duration
        """
        return pulumi.get(self, "duration")

    @_builtins.property
    @pulumi.getter(name="planCode")
    def plan_code(self) -> _builtins.str:
        """
        Plan code
        """
        return pulumi.get(self, "plan_code")

    @_builtins.property
    @pulumi.getter(name="pricingMode")
    def pricing_mode(self) -> _builtins.str:
        """
        Pricing model identifier
        """
        return pulumi.get(self, "pricing_mode")

    @_builtins.property
    @pulumi.getter(name="catalogName")
    def catalog_name(self) -> Optional[_builtins.str]:
        """
        Catalog name
        """
        return pulumi.get(self, "catalog_name")

    @_builtins.property
    @pulumi.getter
    def configurations(self) -> Optional[Sequence['outputs.VrackPlanOptionConfiguration']]:
        """
        Representation of a configuration item for personalizing product
        """
        return pulumi.get(self, "configurations")


@pulumi.output_type
class VrackPlanOptionConfiguration(dict):
    def __init__(__self__, *,
                 label: _builtins.str,
                 value: _builtins.str):
        """
        :param _builtins.str label: Identifier of the resource
        :param _builtins.str value: Path to the resource in API.OVH.COM
        """
        pulumi.set(__self__, "label", label)
        pulumi.set(__self__, "value", value)

    @_builtins.property
    @pulumi.getter
    def label(self) -> _builtins.str:
        """
        Identifier of the resource
        """
        return pulumi.get(self, "label")

    @_builtins.property
    @pulumi.getter
    def value(self) -> _builtins.str:
        """
        Path to the resource in API.OVH.COM
        """
        return pulumi.get(self, "value")





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetCloudProjectGatewayResult',
    'AwaitableGetCloudProjectGatewayResult',
    'get_cloud_project_gateway',
    'get_cloud_project_gateway_output',
]

@pulumi.output_type
class GetCloudProjectGatewayResult:
    """
    A collection of values returned by getCloudProjectGateway.
    """
    def __init__(__self__, external_information=None, id=None, interfaces=None, model=None, name=None, region=None, service_name=None, status=None):
        if external_information and not isinstance(external_information, dict):
            raise TypeError("Expected argument 'external_information' to be a dict")
        pulumi.set(__self__, "external_information", external_information)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if interfaces and not isinstance(interfaces, list):
            raise TypeError("Expected argument 'interfaces' to be a list")
        pulumi.set(__self__, "interfaces", interfaces)
        if model and not isinstance(model, str):
            raise TypeError("Expected argument 'model' to be a str")
        pulumi.set(__self__, "model", model)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter(name="externalInformation")
    def external_information(self) -> 'outputs.GetCloudProjectGatewayExternalInformationResult':
        """
        External information
        """
        return pulumi.get(self, "external_information")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        Id
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def interfaces(self) -> Sequence['outputs.GetCloudProjectGatewayInterfaceResult']:
        """
        Interfaces list of the gateway
        """
        return pulumi.get(self, "interfaces")

    @_builtins.property
    @pulumi.getter
    def model(self) -> _builtins.str:
        """
        Model of the gateway
        """
        return pulumi.get(self, "model")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Name of the gateway
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def region(self) -> _builtins.str:
        """
        Gateway region
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> _builtins.str:
        """
        Service name
        """
        return pulumi.get(self, "service_name")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        Status of the gateway
        """
        return pulumi.get(self, "status")


class AwaitableGetCloudProjectGatewayResult(GetCloudProjectGatewayResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCloudProjectGatewayResult(
            external_information=self.external_information,
            id=self.id,
            interfaces=self.interfaces,
            model=self.model,
            name=self.name,
            region=self.region,
            service_name=self.service_name,
            status=self.status)


def get_cloud_project_gateway(id: Optional[_builtins.str] = None,
                              region: Optional[_builtins.str] = None,
                              service_name: Optional[_builtins.str] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCloudProjectGatewayResult:
    """
    Get gateway

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    gateway = ovh.get_cloud_project_gateway(service_name="<public cloud project ID>",
        region="GRA11",
        id="<gateway ID>")
    ```


    :param _builtins.str id: Id
    :param _builtins.str region: Gateway region
    :param _builtins.str service_name: Service name
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['region'] = region
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:index/getCloudProjectGateway:getCloudProjectGateway', __args__, opts=opts, typ=GetCloudProjectGatewayResult).value

    return AwaitableGetCloudProjectGatewayResult(
        external_information=pulumi.get(__ret__, 'external_information'),
        id=pulumi.get(__ret__, 'id'),
        interfaces=pulumi.get(__ret__, 'interfaces'),
        model=pulumi.get(__ret__, 'model'),
        name=pulumi.get(__ret__, 'name'),
        region=pulumi.get(__ret__, 'region'),
        service_name=pulumi.get(__ret__, 'service_name'),
        status=pulumi.get(__ret__, 'status'))
def get_cloud_project_gateway_output(id: Optional[pulumi.Input[_builtins.str]] = None,
                                     region: Optional[pulumi.Input[_builtins.str]] = None,
                                     service_name: Optional[pulumi.Input[_builtins.str]] = None,
                                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetCloudProjectGatewayResult]:
    """
    Get gateway

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    gateway = ovh.get_cloud_project_gateway(service_name="<public cloud project ID>",
        region="GRA11",
        id="<gateway ID>")
    ```


    :param _builtins.str id: Id
    :param _builtins.str region: Gateway region
    :param _builtins.str service_name: Service name
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['region'] = region
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:index/getCloudProjectGateway:getCloudProjectGateway', __args__, opts=opts, typ=GetCloudProjectGatewayResult)
    return __ret__.apply(lambda __response__: GetCloudProjectGatewayResult(
        external_information=pulumi.get(__response__, 'external_information'),
        id=pulumi.get(__response__, 'id'),
        interfaces=pulumi.get(__response__, 'interfaces'),
        model=pulumi.get(__response__, 'model'),
        name=pulumi.get(__response__, 'name'),
        region=pulumi.get(__response__, 'region'),
        service_name=pulumi.get(__response__, 'service_name'),
        status=pulumi.get(__response__, 'status')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetPrometheusResult',
    'AwaitableGetPrometheusResult',
    'get_prometheus',
    'get_prometheus_output',
]

@pulumi.output_type
class GetPrometheusResult:
    """
    A collection of values returned by getPrometheus.
    """
    def __init__(__self__, cluster_id=None, engine=None, id=None, service_name=None, targets=None, username=None):
        if cluster_id and not isinstance(cluster_id, str):
            raise TypeError("Expected argument 'cluster_id' to be a str")
        pulumi.set(__self__, "cluster_id", cluster_id)
        if engine and not isinstance(engine, str):
            raise TypeError("Expected argument 'engine' to be a str")
        pulumi.set(__self__, "engine", engine)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if targets and not isinstance(targets, list):
            raise TypeError("Expected argument 'targets' to be a list")
        pulumi.set(__self__, "targets", targets)
        if username and not isinstance(username, str):
            raise TypeError("Expected argument 'username' to be a str")
        pulumi.set(__self__, "username", username)

    @_builtins.property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> _builtins.str:
        """
        See Argument Reference above.
        """
        return pulumi.get(self, "cluster_id")

    @_builtins.property
    @pulumi.getter
    def engine(self) -> _builtins.str:
        """
        See Argument Reference above.
        """
        return pulumi.get(self, "engine")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> _builtins.str:
        """
        See Argument Reference above.
        """
        return pulumi.get(self, "service_name")

    @_builtins.property
    @pulumi.getter
    def targets(self) -> Sequence['outputs.GetPrometheusTargetResult']:
        """
        List of all endpoint targets.
        * `Host` - Host of the endpoint.
        * `Port` - Connection port for the endpoint.
        """
        return pulumi.get(self, "targets")

    @_builtins.property
    @pulumi.getter
    def username(self) -> _builtins.str:
        """
        name of the prometheus user.
        """
        return pulumi.get(self, "username")


class AwaitableGetPrometheusResult(GetPrometheusResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPrometheusResult(
            cluster_id=self.cluster_id,
            engine=self.engine,
            id=self.id,
            service_name=self.service_name,
            targets=self.targets,
            username=self.username)


def get_prometheus(cluster_id: Optional[_builtins.str] = None,
                   engine: Optional[_builtins.str] = None,
                   service_name: Optional[_builtins.str] = None,
                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPrometheusResult:
    """
    Use this data source to get information about a prometheus of a database cluster associated with a public cloud project. For mongodb, please use CloudProjectDatabase.MongoDbPrometheus datasource

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    prometheus = ovh.CloudProject.get_prometheus(service_name="XXX",
        engine="YYY",
        cluster_id="ZZZ")
    pulumi.export("name", prometheus.username)
    ```


    :param _builtins.str cluster_id: Cluster ID
    :param _builtins.str engine: The engine of the database cluster you want user information. To get a full list of available engine visit : [public documentation](https://docs.ovh.com/gb/en/publiccloud/databases). Available engines:
    :param _builtins.str service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
    """
    __args__ = dict()
    __args__['clusterId'] = cluster_id
    __args__['engine'] = engine
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:CloudProject/getPrometheus:getPrometheus', __args__, opts=opts, typ=GetPrometheusResult).value

    return AwaitableGetPrometheusResult(
        cluster_id=pulumi.get(__ret__, 'cluster_id'),
        engine=pulumi.get(__ret__, 'engine'),
        id=pulumi.get(__ret__, 'id'),
        service_name=pulumi.get(__ret__, 'service_name'),
        targets=pulumi.get(__ret__, 'targets'),
        username=pulumi.get(__ret__, 'username'))
def get_prometheus_output(cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
                          engine: Optional[pulumi.Input[_builtins.str]] = None,
                          service_name: Optional[pulumi.Input[_builtins.str]] = None,
                          opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetPrometheusResult]:
    """
    Use this data source to get information about a prometheus of a database cluster associated with a public cloud project. For mongodb, please use CloudProjectDatabase.MongoDbPrometheus datasource

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    prometheus = ovh.CloudProject.get_prometheus(service_name="XXX",
        engine="YYY",
        cluster_id="ZZZ")
    pulumi.export("name", prometheus.username)
    ```


    :param _builtins.str cluster_id: Cluster ID
    :param _builtins.str engine: The engine of the database cluster you want user information. To get a full list of available engine visit : [public documentation](https://docs.ovh.com/gb/en/publiccloud/databases). Available engines:
    :param _builtins.str service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
    """
    __args__ = dict()
    __args__['clusterId'] = cluster_id
    __args__['engine'] = engine
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:CloudProject/getPrometheus:getPrometheus', __args__, opts=opts, typ=GetPrometheusResult)
    return __ret__.apply(lambda __response__: GetPrometheusResult(
        cluster_id=pulumi.get(__response__, 'cluster_id'),
        engine=pulumi.get(__response__, 'engine'),
        id=pulumi.get(__response__, 'id'),
        service_name=pulumi.get(__response__, 'service_name'),
        targets=pulumi.get(__response__, 'targets'),
        username=pulumi.get(__response__, 'username')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['StorageEfsShareSnapshotArgs', 'StorageEfsShareSnapshot']

@pulumi.input_type
class StorageEfsShareSnapshotArgs:
    def __init__(__self__, *,
                 service_name: pulumi.Input[_builtins.str],
                 share_id: pulumi.Input[_builtins.str],
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a StorageEfsShareSnapshot resource.
        :param pulumi.Input[_builtins.str] service_name: Service name
        :param pulumi.Input[_builtins.str] share_id: Share ID
        :param pulumi.Input[_builtins.str] description: Snapshot description
        :param pulumi.Input[_builtins.str] name: Snapshot name
        """
        pulumi.set(__self__, "service_name", service_name)
        pulumi.set(__self__, "share_id", share_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Input[_builtins.str]:
        """
        Service name
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "service_name", value)

    @_builtins.property
    @pulumi.getter(name="shareId")
    def share_id(self) -> pulumi.Input[_builtins.str]:
        """
        Share ID
        """
        return pulumi.get(self, "share_id")

    @share_id.setter
    def share_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "share_id", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Snapshot description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Snapshot name
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _StorageEfsShareSnapshotState:
    def __init__(__self__, *,
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 path: Optional[pulumi.Input[_builtins.str]] = None,
                 service_name: Optional[pulumi.Input[_builtins.str]] = None,
                 share_id: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering StorageEfsShareSnapshot resources.
        :param pulumi.Input[_builtins.str] created_at: Snapshot creation date
        :param pulumi.Input[_builtins.str] description: Snapshot description
        :param pulumi.Input[_builtins.str] name: Snapshot name
        :param pulumi.Input[_builtins.str] path: Snapshot path
        :param pulumi.Input[_builtins.str] service_name: Service name
        :param pulumi.Input[_builtins.str] share_id: Share ID
        :param pulumi.Input[_builtins.str] status: Snapshot status
        :param pulumi.Input[_builtins.str] type: Snapshot type
        """
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if path is not None:
            pulumi.set(__self__, "path", path)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if share_id is not None:
            pulumi.set(__self__, "share_id", share_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Snapshot creation date
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Snapshot description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Snapshot name
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def path(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Snapshot path
        """
        return pulumi.get(self, "path")

    @path.setter
    def path(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "path", value)

    @_builtins.property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Service name
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "service_name", value)

    @_builtins.property
    @pulumi.getter(name="shareId")
    def share_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Share ID
        """
        return pulumi.get(self, "share_id")

    @share_id.setter
    def share_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "share_id", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Snapshot status
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Snapshot type
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.type_token("ovh:index/storageEfsShareSnapshot:StorageEfsShareSnapshot")
class StorageEfsShareSnapshot(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 service_name: Optional[pulumi.Input[_builtins.str]] = None,
                 share_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh
        import pulumi_time as time

        efs = ovh.get_storage_efs(service_name="XXX")
        # This resource will destroy (at least) 10 seconds after ovh_storage_efs_share_snapshot resource
        share = ovh.StorageEfsShare("share",
            service_name=efs.service_name,
            name="share",
            description="My share",
            protocol="NFS",
            size=100)
        # This resource adds a delay between ovh_storage_efs_share_snapshot and ovh_storage_efs_share resources destruction
        wait10_seconds = time.index.Sleep("wait_10_seconds", destroy_duration=10s,
        opts = pulumi.ResourceOptions(depends_on=[share]))
        snapshot = ovh.StorageEfsShareSnapshot("snapshot",
            service_name=efs.service_name,
            share_id=share.id,
            name="snapshot",
            description="My snapshot",
            opts = pulumi.ResourceOptions(depends_on=[wait10_seconds]))
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: Snapshot description
        :param pulumi.Input[_builtins.str] name: Snapshot name
        :param pulumi.Input[_builtins.str] service_name: Service name
        :param pulumi.Input[_builtins.str] share_id: Share ID
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: StorageEfsShareSnapshotArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh
        import pulumi_time as time

        efs = ovh.get_storage_efs(service_name="XXX")
        # This resource will destroy (at least) 10 seconds after ovh_storage_efs_share_snapshot resource
        share = ovh.StorageEfsShare("share",
            service_name=efs.service_name,
            name="share",
            description="My share",
            protocol="NFS",
            size=100)
        # This resource adds a delay between ovh_storage_efs_share_snapshot and ovh_storage_efs_share resources destruction
        wait10_seconds = time.index.Sleep("wait_10_seconds", destroy_duration=10s,
        opts = pulumi.ResourceOptions(depends_on=[share]))
        snapshot = ovh.StorageEfsShareSnapshot("snapshot",
            service_name=efs.service_name,
            share_id=share.id,
            name="snapshot",
            description="My snapshot",
            opts = pulumi.ResourceOptions(depends_on=[wait10_seconds]))
        ```

        :param str resource_name: The name of the resource.
        :param StorageEfsShareSnapshotArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(StorageEfsShareSnapshotArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 service_name: Optional[pulumi.Input[_builtins.str]] = None,
                 share_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = StorageEfsShareSnapshotArgs.__new__(StorageEfsShareSnapshotArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["name"] = name
            if service_name is None and not opts.urn:
                raise TypeError("Missing required property 'service_name'")
            __props__.__dict__["service_name"] = service_name
            if share_id is None and not opts.urn:
                raise TypeError("Missing required property 'share_id'")
            __props__.__dict__["share_id"] = share_id
            __props__.__dict__["created_at"] = None
            __props__.__dict__["path"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["type"] = None
        super(StorageEfsShareSnapshot, __self__).__init__(
            'ovh:index/storageEfsShareSnapshot:StorageEfsShareSnapshot',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created_at: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            path: Optional[pulumi.Input[_builtins.str]] = None,
            service_name: Optional[pulumi.Input[_builtins.str]] = None,
            share_id: Optional[pulumi.Input[_builtins.str]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None,
            type: Optional[pulumi.Input[_builtins.str]] = None) -> 'StorageEfsShareSnapshot':
        """
        Get an existing StorageEfsShareSnapshot resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] created_at: Snapshot creation date
        :param pulumi.Input[_builtins.str] description: Snapshot description
        :param pulumi.Input[_builtins.str] name: Snapshot name
        :param pulumi.Input[_builtins.str] path: Snapshot path
        :param pulumi.Input[_builtins.str] service_name: Service name
        :param pulumi.Input[_builtins.str] share_id: Share ID
        :param pulumi.Input[_builtins.str] status: Snapshot status
        :param pulumi.Input[_builtins.str] type: Snapshot type
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _StorageEfsShareSnapshotState.__new__(_StorageEfsShareSnapshotState)

        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["description"] = description
        __props__.__dict__["name"] = name
        __props__.__dict__["path"] = path
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["share_id"] = share_id
        __props__.__dict__["status"] = status
        __props__.__dict__["type"] = type
        return StorageEfsShareSnapshot(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.str]:
        """
        Snapshot creation date
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[_builtins.str]:
        """
        Snapshot description
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Snapshot name
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def path(self) -> pulumi.Output[_builtins.str]:
        """
        Snapshot path
        """
        return pulumi.get(self, "path")

    @_builtins.property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[_builtins.str]:
        """
        Service name
        """
        return pulumi.get(self, "service_name")

    @_builtins.property
    @pulumi.getter(name="shareId")
    def share_id(self) -> pulumi.Output[_builtins.str]:
        """
        Share ID
        """
        return pulumi.get(self, "share_id")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        Snapshot status
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Output[_builtins.str]:
        """
        Snapshot type
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

import types

__config__ = pulumi.Config('ovh')


class _ExportableConfig(types.ModuleType):
    @_builtins.property
    def access_token(self) -> Optional[str]:
        """
        The OVH API Access Token
        """
        return __config__.get('accessToken')

    @_builtins.property
    def api_rate_limit(self) -> Optional[int]:
        """
        Specify the API request rate limit, X operations by seconds (default: unlimited)
        """
        return __config__.get_int('apiRateLimit')

    @_builtins.property
    def application_key(self) -> Optional[str]:
        """
        The OVH API Application Key
        """
        return __config__.get('applicationKey')

    @_builtins.property
    def application_secret(self) -> Optional[str]:
        """
        The OVH API Application Secret
        """
        return __config__.get('applicationSecret')

    @_builtins.property
    def client_id(self) -> Optional[str]:
        """
        OAuth 2.0 application's ID
        """
        return __config__.get('clientId')

    @_builtins.property
    def client_secret(self) -> Optional[str]:
        """
        OAuth 2.0 application's secret
        """
        return __config__.get('clientSecret')

    @_builtins.property
    def consumer_key(self) -> Optional[str]:
        """
        The OVH API Consumer Key
        """
        return __config__.get('consumerKey')

    @_builtins.property
    def endpoint(self) -> Optional[str]:
        """
        The OVH API endpoint to target (ex: "ovh-eu")
        """
        return __config__.get('endpoint')

    @_builtins.property
    def user_agent_extra(self) -> Optional[str]:
        """
        Extra information to append to the user-agent
        """
        return __config__.get('userAgentExtra')

